abacusai.data_quality_results — AbacusAI documentation

# abacusai.data_quality_results

## Classes

`DataQualityResults` | Data Quality results from normalization stage

## Module Contents

class abacusai.data_quality_results.DataQualityResults(client, results=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Data Quality results from normalization stage

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - results (dict) – A list with different pairs of quality parameters and their values

  results
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict